@@ -10,8 +10,8 @@
 
 from chatllm.llmchain.llms.basellm import BaseLLM
 
-from chatllm.llmchain.llms.ernie import ErnieBot
-from chatllm.llmchain.llms.spark import SparkBot
-from chatllm.llmchain.llms.chatglm import ChatGLM
-from chatllm.llmchain.llms.hunyuan import HuanYuan
-from chatllm.llmchain.llms.kimi import Kimi
+# from chatllm.llmchain.llms.ernie import ErnieBot
+# from chatllm.llmchain.llms.spark import SparkBot
+# from chatllm.llmchain.llms.chatglm import ChatGLM
+# from chatllm.llmchain.llms.hunyuan import HuanYuan
+# from chatllm.llmchain.llms.kimi import Kimi
