@@ -10,6 +10,7 @@
 #streamlit run chatfile_nesc_v1.py
 #streamlit run chatbook.py
 
-streamlit run  chatfile_nesc_last.py
+#streamlit run  chatfile_nesc_last.py
 
+streamlit run  chat_copilot.py
 
